@@ -125,6 +125,10 @@ class SeleniumAccount:
             self.__page_name = self.domain.lower().title()
 
         return self.__page_name
+    
+    @property
+    def user_agent(self) -> Optional[str]:
+        return self.browser.user_agent
 
 
     # -------------------------------------------------------- Public methods -------------------------------------------------------- #
@@ -196,14 +200,31 @@ class SeleniumAccount:
     def save_cookies(self) -> None:
         self.browser.save_cookies()
 
-    def get(self, url: str) -> bool:
-        return self.browser.get(url)
+    def get(
+        self,
+        url: str,
+        force: bool = False
+    ) -> bool:
+        return self.browser.get(url, force=force)
 
-    def quit(self) -> None:
+    def quit(self) -> bool:
         try:
-            self.browser.driver.quit()
-        except:
-            pass
+            self.browser.quit()
+
+            return True
+        except Exception as e:
+            print('Error - SeleniumAcc: quit() - ', e)
+
+            return False
+
+
+    # --------------------------------------------------------- Destructor ----------------------------------------------------------- #
+
+    def __del__(self):
+        try:
+            self.quit()
+        except Exception as e:
+            print('Error - SeleniumAcc: __del__() - ', e)
 
 
     # ------------------------------------------------------- Private methods -------------------------------------------------------- #
